@@ -52,7 +52,8 @@ void Stash::_promote (GV* gv, const panda::string_view& key) const {
             U32 hash;
             PERL_HASH(hash, key.data(), key.length());
             HEK* hek = share_hek(key.data(), key.length(), hash);
-            CvNAME_HEK_set((CV*)val, hek);
+            ((XPVCV*)MUTABLE_PTR(SvANY(val)))->xcv_gv_u.xcv_hek = hek;
+            CvNAMED_on((CV*)val);
         }
     }
 #endif
